########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Thursday 01 June 2006 15:55:49 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/AD3Gpf.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#
# $Id: AD3Gpf.py,v 1.1 2006/06/05 22:45:41 rhuey Exp $
#

from NetworkEditor.macros import MacroNode
class AD3Gpf(MacroNode):

    def __init__(self, constrkw={}, name='AD3Gpf', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        net.editor.addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        net.editor.addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        net.editor.addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")


    def afterAddingToNetwork(self):
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        from MolKit.VisionInterface.MolKitNodes import molkitlib
        from Vision.StandardNodes import stdlib
        ## building macro network ##
        AD3Gpf_15 = self
        from traceback import print_exc

        ## loading libraries ##
        from AutoDockTools.VisionInterface.AdtNodes import adtlib
        self.macroNetwork.getEditor().addLibraryInstance(adtlib,"AutoDockTools.VisionInterface.AdtNodes", "adtlib")

        from MolKit.VisionInterface.MolKitNodes import molkitlib
        self.macroNetwork.getEditor().addLibraryInstance(molkitlib,"MolKit.VisionInterface.MolKitNodes", "molkitlib")

        from Vision.StandardNodes import stdlib
        self.macroNetwork.getEditor().addLibraryInstance(stdlib,"Vision.StandardNodes", "stdlib")

        try:
            ## saving node input Ports ##
            input_Ports_16 = self.macroNetwork.ipNode
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_16=None

        try:
            ## saving node output Ports ##
            output_Ports_17 = self.macroNetwork.opNode
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_17=None

        try:
            ## saving node Grid Parameter File Browser ##
            from AutoDockTools.VisionInterface.AdtNodes import GridParameterFileBrowserNE
            Grid_Parameter_File_Browser_18 = GridParameterFileBrowserNE(constrkw = {}, name='Grid Parameter File Browser', library=adtlib)
            self.macroNetwork.addNode(Grid_Parameter_File_Browser_18,310,99)
            apply(Grid_Parameter_File_Browser_18.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Grid_Parameter_File_Browser_18.outputPortByName['filename'].configure, (), {'color': 'white', 'shape': 'oval'})
            Grid_Parameter_File_Browser_18.inputPortByName['filename'].widget.set("/mgl/work4/rhuey/dev23/fri2.gpf", run=False)
        except:
            print "WARNING: failed to restore GridParameterFileBrowserNE named Grid Parameter File Browser in network self.macroNetwork"
            print_exc()
            Grid_Parameter_File_Browser_18=None

        try:
            ## saving node Read Molecule ##
            from MolKit.VisionInterface.MolKitNodes import ReadMolecule
            Read_Molecule_19 = ReadMolecule(constrkw = {}, name='Read Molecule', library=molkitlib)
            self.macroNetwork.addNode(Read_Molecule_19,156,96)
            apply(Read_Molecule_19.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Read_Molecule_19.outputPortByName['MolSets'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore ReadMolecule named Read Molecule in network self.macroNetwork"
            print_exc()
            Read_Molecule_19=None

        try:
            ## saving node Read Molecule ##
            from MolKit.VisionInterface.MolKitNodes import ReadMolecule
            Read_Molecule_20 = ReadMolecule(constrkw = {}, name='Read Molecule', library=molkitlib)
            self.macroNetwork.addNode(Read_Molecule_20,234,98)
            apply(Read_Molecule_20.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Read_Molecule_20.outputPortByName['MolSets'].configure, (), {'color': '#c64e70', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore ReadMolecule named Read Molecule in network self.macroNetwork"
            print_exc()
            Read_Molecule_20=None

        try:
            ## saving node File Browser ##
            from Vision.StandardNodes import FileBrowserNE
            File_Browser_21 = FileBrowserNE(constrkw = {}, name='File Browser', library=stdlib)
            self.macroNetwork.addNode(File_Browser_21,332,163)
            apply(File_Browser_21.inputPortByName['filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(File_Browser_21.outputPortByName['filename'].configure, (), {'color': 'white', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore FileBrowserNE named File Browser in network self.macroNetwork"
            print_exc()
            File_Browser_21=None

        try:
            ## saving node Prepare AD3Gpf ##
            from AutoDockTools.VisionInterface.AdtNodes import AdtPrepareGpf3
            Prepare_AD3Gpf_22 = AdtPrepareGpf3(constrkw = {}, name='Prepare AD3Gpf', library=adtlib)
            self.macroNetwork.addNode(Prepare_AD3Gpf_22,217,216)
            apply(Prepare_AD3Gpf_22.inputPortByName['ligand_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Gpf_22.inputPortByName['receptor_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Gpf_22.inputPortByName['gpf_filename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Gpf_22.inputPortByName['parameters'].configure, (), {'color': 'cyan', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Gpf_22.inputPortByName['outputfilename'].configure, (), {'color': 'white', 'cast': True, 'shape': 'oval'})
            apply(Prepare_AD3Gpf_22.outputPortByName['ag3_parameter_file'].configure, (), {'color': 'white', 'shape': 'oval'})
        except:
            print "WARNING: failed to restore AdtPrepareGpf3 named Prepare AD3Gpf in network self.macroNetwork"
            print_exc()
            Prepare_AD3Gpf_22=None

        self.macroNetwork.freeze()

        ## saving connections for network AD3Gpf ##
        if Read_Molecule_19 is not None and Prepare_AD3Gpf_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Read_Molecule_19, Prepare_AD3Gpf_22, "MolSets", "ligand_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Read_Molecule_19 and Prepare_AD3Gpf_22 in network self.macroNetwork"
        if Read_Molecule_20 is not None and Prepare_AD3Gpf_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Read_Molecule_20, Prepare_AD3Gpf_22, "MolSets", "receptor_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Read_Molecule_20 and Prepare_AD3Gpf_22 in network self.macroNetwork"
        if Grid_Parameter_File_Browser_18 is not None and Prepare_AD3Gpf_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Grid_Parameter_File_Browser_18, Prepare_AD3Gpf_22, "filename", "gpf_filename", blocking=True)
            except:
                print "WARNING: failed to restore connection between Grid_Parameter_File_Browser_18 and Prepare_AD3Gpf_22 in network self.macroNetwork"
        if File_Browser_21 is not None and Prepare_AD3Gpf_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    File_Browser_21, Prepare_AD3Gpf_22, "filename", "outputfilename", blocking=True)
            except:
                print "WARNING: failed to restore connection between File_Browser_21 and Prepare_AD3Gpf_22 in network self.macroNetwork"
        output_Ports_17 = self.macroNetwork.opNode
        if Prepare_AD3Gpf_22 is not None and output_Ports_17 is not None:
            try:
                self.macroNetwork.connectNodes(
                    Prepare_AD3Gpf_22, output_Ports_17, "ag3_parameter_file", "new", blocking=True)
            except:
                print "WARNING: failed to restore connection between Prepare_AD3Gpf_22 and output_Ports_17 in network self.macroNetwork"
        self.macroNetwork.unfreeze()

        AD3Gpf_15.shrink()

        ## reset modifications ##
        AD3Gpf_15.resetTags()
        AD3Gpf_15.buildOriginalList()



#!/usr/bin/env python
#
# $Id: summarize_docking_directory.py,v 1.5 2007/10/09 17:30:07 annao Exp $
#

import logging as log
import os, glob
import numpy.oldnumeric as Numeric
import string

from MolKit import Read
from AutoDockTools.Docking import Docking

if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        """Print helpful, accurate usage statement to stdout."""
        print "Usage: summarize_docking_directory.py -d directory"
        print
        print "    Write docking result summary to stdout."
        print
        print "    Required parameters:"
        print "         -d directory    docking directory"
        print "    Optional parameters:"
        print "        [-l filename]    reference_ligand_filename"
        print "        [-t rmsd]        rmsd tolerance (default is 1.0)"
        print "        [-f]             write to file (name derived from docking)"
        print "        [-o filename]    write to filename"
        print "        [-v]             verbose output"
        print "        [-D]             debugging output"


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'd:l:fo:t:vhD')
    except getopt.GetoptError, msg:
        print 'summarize_docking_directory.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-d: directory
    directory =  None

    # optional parameters

    #-l: ligand_filename
    ligand_filename =  None
    #-t: rms_tolerance
    rms_tolerance =  1.0
    verbose = None
    #-f
    write_to_file = False
    #-o output_filename
    output_filename = None

    for o, a in opt_list:
        if o in ('-d', '--d'):
            directory = a
            log.info("Docking directory: %s" % directory)
        if o in ('-l', '--l'):
            ligand_filename = a
            log.info('set reference ligand_filename to ', ligand_filename)
        if o in ('-o', '--o'):
            output_filename = a
            log.info('set output_filename to ', output_filename)
        if o in ('-t', '--t'):
            rms_tolerance = float(a)
            log.info("Clustering rmsd tolerance %5.2f" % rms_tolerance)
        if o in ('-f', '--f'):
            write_to_file = True
        if o in ('-v', '--v'):
            log.basicConfig(level=log.INFO)
            log.info("verbose output")
        if o in ('-D', '--DEBUG'):
            log.basicConfig(level=log.DEBUG)
            log.debug("debugging output")
        if o in ('-h', '--'):
            usage()
            sys.exit()


    # make sure directory was specified
    if not directory:
        log.error('summarize_docking_directory: docking directory must be specified.')
        usage()
        sys.exit()


    # make sure directory exists
    try:
        os.stat(directory)
    except OSError, msg:
        log.error("summarize_docking_directory: %s: %s",  msg.strerror, msg.filename)
        sys.exit()


    # get absolute, normalized directory_path
    directory_pathname = os.path.abspath(directory) + "/"
    docking_pathname = os.path.dirname(directory_pathname)
    docking_name = string.split(docking_pathname, '/')[-1]

    log.debug("directory: %s" % directory)
    log.debug("directory_pathname: %s" % directory_pathname)
    log.debug("docking_pathname: %s" % docking_pathname)
    log.debug("docking_name: %s" % docking_name)


    output_fileptr = sys.stdout
    if output_filename:
        output_filepath = os.path.join(docking_pathname, output_filename)
        output_fileptr = open(output_filepath, 'w')
        log.info("Writing to %s" % output_filepath)
    else:
        if write_to_file:
            # create output filename from directory and rms_tolerance
            output_filepath = os.path.join(docking_pathname, docking_name) + \
                              '-' + str(rms_tolerance)+ ".csv"
            output_fileptr = open(output_filepath, 'w')
            log.info("Writing to %s" % output_filepath)
            
    # use the directory name to deduce dpf and gpf names
    # get all ligand and receptors filename from dpf and gpf
    
    # @@ ASSUMPTIONS: WCG conventions for dpf and gpf names @@
    # @@ from docking directory name                        @@
    dpf_pathname = os.path.join(docking_pathname, docking_name) + ".dpf"
    dpf_filename = os.path.basename(dpf_pathname)
    # remove "faahNNNN_ from docking name
    gpf_pathname = os.path.join(docking_pathname, docking_name[9:]) + ".gpf"
    gpf_filename = os.path.basename(gpf_pathname)

    #
    # get filenames from the dpf and gpf
    #
    from AutoDockTools.DockingParameters import DockingParameters
    from AutoDockTools.GridParameters import GridParameters

    dpo = DockingParameters()
    log.info("reading dpf: %s" % dpf_pathname)
    dpo.read(dpf_pathname)
    ligand_filename = dpo["move"]["value"]
    ligand_pathname = os.path.join(docking_pathname, ligand_filename)
    log.info ("ligand_filename: %s" % ligand_filename)
    log.debug("ligand_pathname: %s" % ligand_pathname)

    gpo = GridParameters()
    log.info("reading gpf: %s" % gpf_pathname)
    gpo.read(gpf_pathname)
    receptor_filename = gpo["receptor"]["value"]
    receptor_pathname = os.path.join(docking_pathname, receptor_filename)
    log.info ("receptor_filename: %s" % receptor_filename)
    log.debug("receptor_pathname: %s" % receptor_pathname)

    # docking log pathnames
    dlg_pathname_list = glob.glob(os.path.join( docking_pathname, '*.dlg'))

    # At this point, we have pathnames and filenames for all the
    # input and output files, start reading them
    ######################################################################
   
    # the ligand from the dpf
    dpf_ligand = Read(ligand_pathname)[0]

    #read all the docking logs in as one Docking
    d = Docking()
    for dlg in dlg_pathname_list:
        log.debug("reading dlg: %s" % dlg)
##         d.readDlg(dlg, ligand=dpf_ligand)
        d.readDlg(dlg)

    # set up the clusterer to use the HIV PR c2 specific getRMSD_custom method
    d.clusterer.set_get_distance( d.clusterer._get_distance_custom)

    log.info("clustering %s at rms_tol %f" % (docking_name, rms_tolerance))
    d.clusterer.make_clustering(rms_tolerance)
##     d.clusterer.clustering_dict[rms_tolerance].do_stats()
##     d.clusterer.write_summary()


    # create an output dictionary from the clustering

    ol = [] # output list
    seed = d.clusterer.clustering_dict[rms_tolerance][0][0]
    for cx, cluster in enumerate(d.clusterer.clustering_dict[rms_tolerance]):
        od = {} # output dictionary for this cluster
        conf = cluster[0]

        # general info about docking
        od['num_conf_docking'] = "%7d" % (len(d.clusterer.data))
        od['ntors'] = "%7d" % (len(conf.torsions))
        od['natoms'] = "%7d" % (len(conf.coords))

        # general info about this clustering
        od['num_clusters'] = "%7d" % (len(d.clusterer.clustering_dict[rms_tolerance]))
        od['rmstol'] = "%7.3f" % (rms_tolerance)
        
        # specific info about this cluster
        od['num_conf_cluster'] = " %7d" % (len(cluster))
        od['energy'] = "%8.3f" % (conf.binding_energy)
        od['clust_rmsd'] = "%7.3f" % (d.clusterer.get_distance(seed, conf))
        od['cluster_ix'] = "%7d" % (cx+1)

        # search for the seed conformation in the docking logs
        od['dlg'] = "%32s" % (docking_name) # default to this if search (below) fails
        for dlo in d.dlo_list:
            if conf in dlo.conformations:
                od['dlg'] = "%32s" % \
                            (os.path.splitext(os.path.basename(dlo.parser.filename))[0])

        log.debug(od)
        ol.append(od)

    log.debug(od['energy'])
    log.debug(od['clust_rmsd'])
    log.debug(type(od['energy']))
    log.debug(type(od['clust_rmsd']))


    # the ol list of od's should already be sorted by cluster energy
    pass
    
    # initialize output header dictionary (same keys as od)
    oh = {}
    for key in od.keys():
        oh[key] = "<%s header>" % key # init with generic values
    # now put in less-generic? values
    oh['num_conf_docking'] = "%7s" % ( "#conf")
    oh['ntors']            = "%7s" % ( "#tors")
    oh['natoms']           = "%7s" % ( "#ats")
    oh['num_clusters']     = "%7s" % ( "#clust")
    oh['rmstol']           = "%7s" % ( "rmstol")
    oh['num_conf_cluster'] = "%8s" % ( "Csize")
    oh['energy']           = "%8s" % ( "LE")
    oh['clust_rmsd']       = "%7s" % ( "rmsd")
    oh['cluster_ix']       = "%7s" % ( "Crank")
    oh['dlg']              = "%32s" % ( "docking_filename")

    # write the csv
    import csv
    fields = ['dlg',
              'energy',
              'clust_rmsd',
              'num_conf_cluster',
              'cluster_ix',
              'num_clusters',
              'rmstol',
              'num_conf_docking',
              'natoms',
              'ntors']

    writer = csv.DictWriter( output_fileptr, fieldnames=fields, restval="@@")
    writer.writerow(oh)
    writer.writerows(ol)

    log.debug("exiting...")
    sys.exit()


    
    

# To execute this command type:
# summarize_with_rotated_rmsd.py -d directory -t rmsd tolerance -b report best docking
# only -r receptor filename  -k build hydrogen bonds -v




#
#
#  $Id: test_LibraryPfWriters.py,v 1.1 2004/06/17 21:40:07 rhuey Exp $
#
#

import unittest
import glob, os, string
from AutoDockTools.lib_parameter_file_writer import LibraryGpfWriter, LibraryDpfWriter 



class LibraryGridParamFileWriter(unittest.TestCase):
    """
    class to test writing Autogrid Parameter files for all ligand types in a
    library
    """

    def setUp(self):
        """
        initialize
        """
        self.gpffile = 'hsg1.gpf'
        self.writer = LibraryGpfWriter(self.gpffile, extension = "out.pdbq", 
                                        prefix="test_lgp_")
        self.atomtypes = ['A','H','C','O','N']


    def tearDown(self):
        """
        clean-up
        """
        cmd = "rm -f test_lgp_*.gpf"
        os.system(cmd)
        delattr(self, 'writer')
        

    def test_write_file0(self):
        """
        check code doesnot crash
        """
        self.writer.write(self.writer.gpo)
        self.assertEqual(1, 1)


    def test_write_file(self):
        """
        check gpf file is created
        """
        self.writer.write(self.writer.gpo)
        outputfilename = "test_lgp_hsg1_0_library.gpf"
        self.assertEqual(os.path.exists(outputfilename), True)



class LibraryDockingParamFileWriter(unittest.TestCase):
    """
    class to test writing docking parameter files for all ligand files in a
    library
    """

    def setUp(self):
        """
        initialize
        """
        self.dpffile = 'hsg1_ind.dpf'
        self.writer = LibraryDpfWriter(self.dpffile, extension = "out.pdbq",
                                               prefix = "test_ldp_")
        self.files_to_remove = []
        for k in ['C','A','N','O','H','S']:
            mapname = 'hsg1.'+ k +'.map'
            if not os.path.exists(mapname):
                cmd = 'touch ' + mapname
                #print "touched ", mapname
                os.system(cmd)
                self.files_to_remove.append(mapname)
        


    def tearDown(self):
        """
        clean-up
        """
        cmd = "rm -f test_ldp_*"
        os.system(cmd)
        for f in self.files_to_remove:
            cmd = "rm -f " + f
            os.system(cmd)
            #print "removed ", f
        delattr(self, 'writer')
        

    def test_write_file0(self):
        """
        check code does not crash
        """
        self.writer.write(self.writer.dpo)
        self.assertEqual(1, 1)


    def test_write_file(self):
        """
        check dpf files are created
        """
        self.writer.write(self.writer.dpo, 'GALS')
        GALSfiles = glob.glob("*GALS.dpf")
        self.assertEqual(len(GALSfiles)>0, True)


    def test_no_errors_written(self):
        """
        check write_lib_dpf_errors is empty
        """
        self.writer.write(self.writer.dpo, 'GALS')
        errptr= open("write_lib_dpf_errors")
        self.assertEqual(len(errptr.readlines()), 0)


    def test_correct_number_of_files_written(self):
        """
        check correct number of dpf files are written
        """
        #get old number of dpf files
        old_number_dpffiles = len(glob.glob("*GALS.dpf"))
        #get number of ligand files
        key = "*" + self.writer.extension
        number_ligand_files = len(glob.glob(key))
        #write dpffiles
        self.writer.write(self.writer.dpo, 'GALS')
        #get new number of dpf files
        new_number_dpffiles = len(glob.glob("*GALS.dpf"))
        self.assertEqual(new_number_dpffiles, number_ligand_files + old_number_dpffiles)


if __name__ == '__main__':
    unittest.main()







########################################################################
#
#    Vision Macro - Python source code - file generated by vision
#    Thursday 05 May 2011 15:54:07 
#    
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Daniel Stoffler, Michel Sanner and TSRI
#   
# revision: Guillaume Vareille
#  
#########################################################################
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/VisionInterface/Adt/Macro/PrepareSingleLigand.py,v 1.2 2011/05/05 23:05:56 jren Exp $
#
# $Id: PrepareSingleLigand.py,v 1.2 2011/05/05 23:05:56 jren Exp $
#

from NetworkEditor.macros import MacroNode
from NetworkEditor.macros import MacroNode
class PrepareSingleLigand(MacroNode):
    '''
        Runs web service for prepare single ligand
        
        Input 1: Unprepared ligand file
        Input 2: Directory to download output to

        Output 1: Path to downloaded prepared receptor file
        Output 2: URL to prepared receptor 
    '''

    def __init__(self, constrkw={}, name='PrepareSingleLigand', **kw):
        kw['name'] = name
        apply( MacroNode.__init__, (self,), kw)

    def beforeAddingToNetwork(self, net):
        MacroNode.beforeAddingToNetwork(self, net)
        from WebServices.VisionInterface.WSNodes import wslib
        net.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass

    def afterAddingToNetwork(self):
        masterNet = self.macroNetwork
        from NetworkEditor.macros import MacroNode
        MacroNode.afterAddingToNetwork(self)
        from WebServices.VisionInterface.WSNodes import wslib
        ## building macro network ##
        PrepareSingleLigand_18 = self
        from traceback import print_exc
        from WebServices.VisionInterface.WSNodes import wslib
        masterNet.getEditor().addLibraryInstance(wslib,"WebServices.VisionInterface.WSNodes", "wslib")
        from WebServices.VisionInterface.WSNodes import addOpalServerAsCategory
        try:
            addOpalServerAsCategory("http://kryptonite.nbcr.net/opal2", replace=False)
        except:
            pass
        try:
            ## saving node input Ports ##
            input_Ports_19 = self.macroNetwork.ipNode
            apply(input_Ports_19.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroInputNode named input Ports in network self.macroNetwork"
            print_exc()
            input_Ports_19=None

        try:
            ## saving node output Ports ##
            output_Ports_20 = self.macroNetwork.opNode
            apply(output_Ports_20.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore MacroOutputNode named output Ports in network self.macroNetwork"
            print_exc()
            output_Ports_20=None

        try:
            ## saving node PrepareLigandSingle_kryptonite_nbcr_net ##
            from NetworkEditor.items import FunctionNode
            PrepareLigandSingle_kryptonite_nbcr_net_21 = FunctionNode(functionOrString='PrepareLigandSingle_kryptonite_nbcr_net', host="http://kryptonite.nbcr.net/opal2", namedArgs={'A': '', 'C': False, 'B': '', 'ligand': '', 'g': False, 'F': False, 'I': '', 'M': False, 'p': '', 'R': '', 'U': '', 'v': False, 'Z': False, 'localRun': False, 'execPath': '', 'd': ''}, constrkw={'functionOrString': "'PrepareLigandSingle_kryptonite_nbcr_net'", 'host': '"http://kryptonite.nbcr.net/opal2"', 'namedArgs': {'A': '', 'C': False, 'B': '', 'ligand': '', 'g': False, 'F': False, 'I': '', 'M': False, 'p': '', 'R': '', 'U': '', 'v': False, 'Z': False, 'localRun': False, 'execPath': '', 'd': ''}}, name='PrepareLigandSingle_kryptonite_nbcr_net', library=wslib)
            self.macroNetwork.addNode(PrepareLigandSingle_kryptonite_nbcr_net_21,217,92)
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['A'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['C'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['B'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['ligand'].configure, (), {'defaultValue': None, 'required': True})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['g'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['F'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['I'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['M'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['p'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['R'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['U'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['v'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['Z'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['localRun'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['execPath'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['d'].configure, (), {'defaultValue': None})
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['A'].widget.configure, (), {'choices': ('bonds_hydrogens', 'bonds', 'hydrogens')})
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['A'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['C'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['B'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['ligand'].rebindWidget()
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['ligand'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['ligand'].unbindWidget()
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['g'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['F'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['I'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['M'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['p'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['R'].widget.set(r"", run=False)
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['U'].widget.configure, (), {'choices': ('nphs_lps', 'nphs', 'lps')})
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['U'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['v'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['Z'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['localRun'].widget.set(0, run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['execPath'].widget.set(r"", run=False)
            PrepareLigandSingle_kryptonite_nbcr_net_21.inputPortByName['d'].widget.set(r"", run=False)
            apply(PrepareLigandSingle_kryptonite_nbcr_net_21.configure, (), {'paramPanelImmediate': 1, 'expanded': False})
        except:
            print "WARNING: failed to restore FunctionNode named PrepareLigandSingle_kryptonite_nbcr_net in network self.macroNetwork"
            print_exc()
            PrepareLigandSingle_kryptonite_nbcr_net_21=None

        try:
            ## saving node GetURLFromList ##
            from WebServices.VisionInterface.WSNodes import GetURLFromListNode
            GetURLFromList_22 = GetURLFromListNode(constrkw={}, name='GetURLFromList', library=wslib)
            self.macroNetwork.addNode(GetURLFromList_22,217,171)
            apply(GetURLFromList_22.inputPortByName['urllist'].configure, (), {'defaultValue': None})
            apply(GetURLFromList_22.inputPortByName['ext'].configure, (), {'defaultValue': None})
            GetURLFromList_22.inputPortByName['ext'].widget.set(r"pdbqt", run=False)
            apply(GetURLFromList_22.configure, (), {'paramPanelImmediate': 1})
        except:
            print "WARNING: failed to restore GetURLFromListNode named GetURLFromList in network self.macroNetwork"
            print_exc()
            GetURLFromList_22=None

        #self.macroNetwork.run()
        self.macroNetwork.freeze()

        ## saving connections for network PrepareSingleLigand ##
        if PrepareLigandSingle_kryptonite_nbcr_net_21 is not None and GetURLFromList_22 is not None:
            try:
                self.macroNetwork.connectNodes(
                    PrepareLigandSingle_kryptonite_nbcr_net_21, GetURLFromList_22, "result", "urllist", blocking=True
                    , splitratio=[0.32868238447942777, 0.66102005033481848])
            except:
                print "WARNING: failed to restore connection between PrepareLigandSingle_kryptonite_nbcr_net_21 and GetURLFromList_22 in network self.macroNetwork"
        output_Ports_20 = self.macroNetwork.opNode
        if GetURLFromList_22 is not None and output_Ports_20 is not None:
            try:
                self.macroNetwork.connectNodes(
                    GetURLFromList_22, output_Ports_20, "url", "new", blocking=True
                    , splitratio=[0.24357139972148803, 0.60352121442381113])
            except:
                print "WARNING: failed to restore connection between GetURLFromList_22 and output_Ports_20 in network self.macroNetwork"
        input_Ports_19 = self.macroNetwork.ipNode
        if input_Ports_19 is not None and PrepareLigandSingle_kryptonite_nbcr_net_21 is not None:
            try:
                self.macroNetwork.connectNodes(
                    input_Ports_19, PrepareLigandSingle_kryptonite_nbcr_net_21, "new", "ligand", blocking=True
                    , splitratio=[0.58130558930809739, 0.62673128127582967])
            except:
                print "WARNING: failed to restore connection between input_Ports_19 and PrepareLigandSingle_kryptonite_nbcr_net_21 in network self.macroNetwork"
        self.macroNetwork.runOnNewData.value = True

        ## modifying MacroInputNode dynamic ports
        input_Ports_19 = self.macroNetwork.ipNode
        input_Ports_19.outputPorts[1].configure(name='PrepareLigandSingle_kryptonite_nbcr_net_ligand')

        ## modifying MacroOutputNode dynamic ports
        output_Ports_20 = self.macroNetwork.opNode
        output_Ports_20.inputPorts[1].configure(singleConnection='auto')
        output_Ports_20.inputPorts[1].configure(name='GetURLFromList_url')
        ## configure MacroNode input ports
        PrepareSingleLigand_18.inputPorts[0].configure(name='PrepareLigandSingle_kryptonite_nbcr_net_ligand')
        PrepareSingleLigand_18.inputPorts[0].configure(datatype='string')
        ## configure MacroNode output ports
        PrepareSingleLigand_18.outputPorts[0].configure(name='GetURLFromList_url')
        PrepareSingleLigand_18.outputPorts[0].configure(datatype='string')

        PrepareSingleLigand_18.shrink()

        ## reset modifications ##
        PrepareSingleLigand_18.resetTags()
        PrepareSingleLigand_18.buildOriginalList()



##########################################################################
#   Authors: Sowjanya Karnati,Ruth Huey
#
#
##########################################################################

# $Id: test_ConfPlayer.py,v 1.7 2008/10/03 20:49:22 sargis Exp $
import unittest
import AutoDockTools.ConfPlayer
from AutoDockTools.ConfPlayer import ConformationPlayer
mv = None
ct = 0 
totalCt =14
class ConfPlayerBaseTest(unittest.TestCase):
    
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(withShell=False,logMode='no',trapExceptions=False)
            mv.loadModule('autotorsCommands', 'AutoDockTools')
            mv.loadModule('autogpfCommands', 'AutoDockTools')
            mv.loadModule('autodpfCommands', 'AutoDockTools')
            #8/18:
            mv.loadModule('autoanalyzeCommands', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
            
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()


    def tearDown(self):
        """
        clean-up
        """
        #print 'in gpf tearDown'
        global ct, totalCt
        #reset docked
        from AutoDockTools.Docking import Docking
        self.mv.docked = None
        for key in self.mv.dockings.keys():
            self.mv.ADanalyze_deleteDLG(key)
        self.mv.dockings = {}
        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m) 
        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv    
    
    
    
    
class ConfPlayerTests(ConfPlayerBaseTest):

    
    def test_confplayer_play_play_reverse(self):
        """tests ConfPlayer play,playrev buttons:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling confplayer
        player =ConformationPlayer(mol =self.mv.Mols[0],docking = self.mv.dockings['ind.dlg'],vf  = self.mv,sequenceList = self.mv.docked.ch.conformations)
        player.Play_cb()
        self.assertEqual(player.currentFrameIndex,10)
        player.PlayRev_cb()
        self.assertEqual(player.currentFrameIndex,0)
        player.Close_cb()

    def test_confplayer_play_go_to_start(self):
        """tests ConfPlayer go to Start button:"""
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =self.mv.Mols[0],docking = self.mv.dockings['ind.dlg'],vf  = self.mv,sequenceList = self.mv.docked.ch.conformations)
        player.Play_cb()
        self.assertEqual(player.currentFrameIndex,10)
        player.GoToStart_cb()
        self.assertEqual(player.currentFrameIndex,0)
        player.Close_cb()
        
    def test_confplayer_play_go_to_end(self):
        """tests ConfPlayer go to end button:
        """
        #read ldocking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =self.mv.Mols[0],docking = self.mv.dockings['ind.dlg'],vf  = self.mv,sequenceList = self.mv.docked.ch.conformations)
        player.PlayRev_cb()
        self.assertEqual(player.currentFrameIndex,0)
        player.GoToEnd_cb()
        self.assertEqual(player.currentFrameIndex,10)
        player.Close_cb()
    
    def test_confplayer_fast_forward_cb_reverse_cb(self):
        """tests ConfPlayer forward,reverse buttons:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =self.mv.Mols[0],docking = self.mv.dockings['ind.dlg'],vf  = self.mv,sequenceList = self.mv.docked.ch.conformations)
        player.FastForward_cb()
        self.assertEqual(player.currentFrameIndex,10)
        player.FastReverse_cb()
        self.assertEqual(player.currentFrameIndex,0)
        player.Close_cb()
    
    
    def test_confplayer_build_hbonds(self):
        """tests ConfPlayer Build H bonds button:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.ADanalyze_readMacromolecule('hsg1.pdbqs', log=0)
        self.mv.colorByMolecules("ind_out;hsg1", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        player.SetState_cb(1)
        #calling setplay options widget
        player.SetMode_cb()
        player.buildHBondVar.set(1)
        player.buildHBonds()
        c = self.mv.showHBonds
        c.showDistLabels.set(1)
        c.showDistances()
        x = len(mv.allAtoms.get(lambda x: hasattr(x, 'hbonds')).name)/3.
        #tests no.of hydrogen bonds formed  = dlabs displayed
        self.assertEqual(int(round(x)),len(c.dlabs))
        self.mv.showHBonds.dismiss_cb()
        player.cancelPlayMode_cb()
        player.Close_cb()
        
        
    def test_confplayer_show_info(self):
        """tests ConfPlayer show info button:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        #calling setplay options widget
        player.SetMode_cb()
        player.nextFrame(1)
        player.showStatsVar.set(1)
        player.showStats()
        #player.statsForm.root.wait_visibility(player.statsForm.root)
        #tests conformation info widget is opened
        self.assertEqual(player.statsForm.root.winfo_ismapped(),1)
        player.cancelPlayMode_cb()
        player.Close_cb()
        player.CloseStats_cb()
        
    def test_confpalyer_show_conflist(self):
        """tests ConfPlayer show conf list:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        #calling setplay options widget
        player.SetMode_cb()
        player.showListVar.set(1)
        player.showStatesList()
        #player.playModeForm.form3.root.wait_visibility(player.playModeForm.form3.root)
        #tests opens choose conformation widget is opened
        self.assertEqual(player.playModeForm.form3.root.winfo_ismapped(),1)
        player.showListVar.set(0)
        player.showStatesList()
        player.cancelPlayMode_cb()
        player.Close_cb()
        
    def test_confplayer_make_rms_ref(self):
        """tests ConfPlayer make rms ref:
        """
        #read docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        #calling setplay options widget
        player.nextFrame(1)
        player.SetMode_cb()
        player.MakeRef_cb()
        player.showStatsVar.set(1)
        player.showStats()
        from string import split
        #tests clrms is 0.0 for that conformation ,when make rms ref button clicked
        label_wid = player.statsForm.widgetID_entries.values()[0]['widget']
        text = label_wid.cget('text')
        self.assertEqual(text.split()[-4],'clRMS=0.0')
        #self.assertEqual(split(split(str(player.statsForm.widgetID_entries.values()[0]),',')[8],'\\n')[5],'clRMS=0.0')
        player.cancelPlayMode_cb()
        player.Close_cb()
        player.CloseStats_cb()
        
    def test_confplayer_choose_rms_ref(self):
        """tests ConfPlayer choose rms ref:
        """
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        #calling setplay options widget
        player.SetMode_cb()
        player.SetRMSRef_cb()
        #setting rmsref mol 
        player.chooser.ipf.entryByName['Molecule']['widget'].selectItem(0)
        player.rmsRefMolecule_cb()
        self.assertEqual(player.rmsRef.name,'ind_out')
        player.cancelPlayMode_cb()
        player.Close_cb()
        
    def test_confplayer_play_mode(self):
        """tests ConfPlayer play mode:
        """
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        #calling setplay options widget
        player.SetMode_cb()
        player.buildPlayModeMenu()
        #invoking options in playMode button
        player.playModeMb.menu.invoke(1)
        self.assertEqual(player.playMode,0)
        player.playModeMb.menu.invoke(2)
        self.assertEqual(player.playMode,1)
        player.playModeMb.menu.invoke(3)
        self.assertEqual(player.playMode,2)
        player.playModeMb.menu.invoke(4)
        self.assertEqual(player.playMode,3)
        player.cancelPlayMode_cb()
        player.Close_cb()
        
    def test_confplayer_play_parameters(self):
        """tests confplayer play parameters:
        """
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        self.mv.ADanalyze_showStates("ind_out")
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        self.mv.Mols[0].spw = player
        #calling setplay options widget
        player.SetMode_cb()
        player.showFrameParms_cb()
        player.showFrameParmWidgets.set(1)
        #setting options in play parameters button
        player.framerateWidget.set(10)
        player.startFrameWidget.set(2)
        player.endFrameWidget.set(8)
        player.stepSizeWidget.set(2)
        player.GoToStart_cb()
        self.assertEqual(player.currentFrameIndex,2)
        player.GoToEnd_cb()
        self.assertEqual(player.currentFrameIndex,8)
        self.assertEqual(player.stepSize,2)
        self.assertEqual(player.framerate,10)
        player.framerateWidget.set(15)
        player.startFrameWidget.set(0)
        player.endFrameWidget.set(10)
        player.stepSizeWidget.set(1) 
        player.cancelPlayMode_cb()
        player.Close_cb()
        
    def test_confplayer_buildcurrent(self):
        """tests confpalyer build current:
        """
        #reading docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        self.mv.ADanalyze_showStates("ind_out")
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        player.SetMode_cb()
        player.nextFrame(1)
        #testing buildcurrent button
        player.Build_cb()
        self.assertEqual(len(self.mv.Mols.name),2)
        self.assertEqual(self.mv.Mols.name,['ind_out', 'ind_out_conf_1'])
        player.cancelPlayMode_cb()
        player.Close_cb() 
    
        
    def test_confplayer_buildall(self):
        """tests confplayer build all:
        """
        #reading docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByMolecules("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        self.mv.ADanalyze_showStates("ind_out")
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        player.SetMode_cb()
        #testing buildall button
        player.BuildAll_cb()
        self.assertEqual(len(self.mv.Mols.name),11)
        player.cancelPlayMode_cb()
        player.Close_cb()
        while len(self.mv.Mols):
            self.mv.deleteMol(self.mv.Mols[-1]) 

    def test_confplayer_colortype(self):
        """tests confpalyer color by button
        """
        #reading docking log
        self.mv.ADanalyze_readDLG('./ind.dlg', 0, 1, log=0)
        self.mv.colorByAtomType("ind_out", ('lines',), log=0)
        self.mv.setUserPreference(('Player GUI', 'ConformationPlayer'), log=0)
        self.mv.ADanalyze_showStates("ind_out")
        #calling player
        player =ConformationPlayer(mol =mv.Mols[0],docking = mv.dockings['ind.dlg'],vf  = mv,sequenceList = mv.docked.ch.conformations)
        oldcolor = mv.allAtoms.colors['lines']
        #testing color by button setting entry as molecule
        player.SetMode_cb()
        player.playModeForm.ent3.delete(0,'end')
        player.playModeForm.ent3.insert(0,'molecule')
        player.updateColor()
        newcolor = mv.allAtoms.colors['lines']
        self.assertEqual(oldcolor!=newcolor,True)





if __name__ == '__main__':
    unittest.main()
    



########################################################################
#
# Date: Jan 2006 Authors: Guillaume Vareille, Michel Sanner
#
#    vareille@scripps.edu
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Guillaume Vareille, Michel Sanner and TSRI
#
#    Vision Library Types
#
#########################################################################
#
# /home/vareille/.mgltools/1.6.0/Vision/UserLibs/MyDefaultLib/libTypes.py
# Vision will generate this file automatically if it can't find it
#
from LigandDB import LigandDB
from receptor import receptor
from receptor_prepared import receptor_prepared
from dpf_template import dpf_template
from gpf_template import gpf_template
from autogrid_results import autogrid_results
from NetworkEditor.datatypes import AnyArrayType

###################################################
# add new types to your library
###################################################

#class ThingType(AnyArrayType):
#
#    from ThingPackage import Thing
#    def __init__(self, name='thing', color='#995699', shape='rect',
#                 klass=Thing):
#
#        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
#                              klass=klass)
#
## in NetworkEditor.datatypes, you should have a look at the class IntType

class LigandDBType(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.LigandDB import LigandDB
    def __init__(self, name='LigandDB', color='#FFCCFF', shape='rect',
                 klass=LigandDB):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

class receptor(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.receptor import receptor
    def __init__(self, name='receptor', color='#99FF33', shape='triangle',
                 klass=receptor):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

class receptor_prepared(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.receptor_prepared import receptor_prepared
    def __init__(self, name='receptor_prepared', color='#009900', shape='triangle',
                 klass=receptor_prepared):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

class dpf_template(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.dpf_template import dpf_template
    def __init__(self, name='dpf_template', color='#9933FF', shape='triangle',
                 klass=dpf_template):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

class gpf_template(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.gpf_template import gpf_template
    def __init__(self, name='gpf_template', color='#FF3333', shape='triangle',
                 klass=gpf_template):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

class autogrid_results(AnyArrayType):
    
    from AutoDockTools.VisionInterface.Adt.autogrid_results import autogrid_results
    def __init__(self, name='autogrid_results', color='#FF33CC', shape='triangle',
                 klass=autogrid_results):

        AnyArrayType.__init__(self, name=name, color=color, shape=shape, 
                              klass=klass)

## in NetworkEditor.datatypes, you should have a look at the class IntType



#
#
#  $Id: test_AD4dpf.py,v 1.14 2014/04/21 17:18:25 rhuey Exp $
#
#


import unittest, glob, os
import time
from string import split, find, strip

mv = None
ct = 0
totalCt = 38


class ADdpf4_BaseTests(unittest.TestCase):
    """
    setUp + tearDown form a fixture: working environment for the testing code
    """
    
        
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(trapExceptions=False)
            mv.loadModule('autotorsCommands', 'AutoDockTools')
            mv.loadModule('autogpfCommands', 'AutoDockTools')
            mv.loadModule('autodpfCommands', 'AutoDockTools')
            #8/18:
            mv.loadModule('autoanalyzeCommands', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()


    def tearDown(self):
        """
        clean-up
        """
        #print 'in gpf tearDown'
        global ct, totalCt
        #reset docked
        from AutoDockTools.DockingParameters import DockingParameters
        self.mv.dpo = DockingParameters()
        self.mv.dpo.vf = self.mv
        from AutoDockTools.GridParameters import GridParameters
        self.mv.gpo = GridParameters()
        self.mv.gpo.vf=self.mv
        self.mv.DPF_LIGAND_TYPES = []
        self.mv.DPF_FLEXRES_TYPES = []

        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m)
        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv            
    

    def SA_GA_LS_GALS(self):    
        self.mv.ADdpf4_writeSA("ref4_SA.dpf")
        self.mv.ADdpf4_writeGA("ref4_GA.dpf")
        self.mv.ADdpf4_writeLS("ref4_LS.dpf")
        self.mv.ADdpf4_writeGAlS("ref4_GALS.dpf")



class ADdpf4_readDPFTests(ADdpf4_BaseTests):
    
    
    def test_dpf_readdpf(self):
        """reads a dpf and checks
        """ 
        filename = 'ref_1ebg.dpf'
        self.mv.ADdpf_read(filename)
        c=self.mv.dpo
        self.assertEqual(c.dpf_filename, filename)


    def test_dpf_read_empty_dpf(self):
        """checks empty dpf entry
        """
        self.assertRaises(IOError, self.mv.ADdpf_read, " ")


    def test_dpf_read_non_existent_dpf(self):
        """checks non-existent dpf
        """
        self.assertRaises(IOError, self.mv.ADdpf_read, "asd.hfd.dpf")
    
   
    def test_dpf_set_macro_molecule_file_name(self):
        """checks  macro mols filename
        """
        filename = "1ebg_rec.pdbqt"
        self.mv.ADdpf4_readMacromolecule(filename)
        self.assertEqual(self.mv.dpo.receptor_filename, filename)
             

    def test_dpf_read_empty_macro_mol(self):
   
        """checks empty macro mol entry
        """
        self.assertRaises(IOError, self.mv.ADdpf4_readMacromolecule, " ")


    def test_dpf_read_non_existent_macro_mol(self):
        """checks non-existent macro mol        """
        self.assertRaises(IOError, self.mv.ADdpf4_readMacromolecule, "asd.hfd.dpf")
    

    def test_dpf_replace_random(self):
        """ checks by setting some values in place of random
        """
        self.mv.ADdpf_read('ref_1ebg.dpf')
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        teststring = "1.0 2.0 3.0"
        self.mv.ADdpf_setDpo(tran0=teststring)
        testfile = "whateveryouwant.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        for l in alllines:
            if find(l, 'tran0')==0:
                break
        ll = split(l)
        testsplit = split(teststring)
        for i in range(1, 4):
            self.assertEqual(ll[i], testsplit[i-1])
   

    def test_chosen_ligand_name(self):
        
        """checks chosen ligand name
        """
        self.mv.readMolecule('1ebg_lig.pdbqt')
        lig_name = self.mv.Mols[0].name
        self.mv.ADdpf4_chooseFormattedLigand(lig_name)
        self.assertEqual(self.mv.dpo.ligand.name, lig_name)
        

    def test_dpf_set_ligand_parameters(self):
        """ checks ligand name, ndihe, center, types
        """
        filename = '1ebg_lig.pdbqt'
        self.mv.readMolecule(filename)
        m=self.mv.Mols[0]
        self.mv.ADdpf4_chooseFormattedLigand(m.name)
        #4assertions: move is ligand.parser.filename
        #ndihe == ligand.ndihe
        #types == ligand.types
        #about==ligand.center
        center = m.getCenter()
        cen2 = []
        for i in range(3):
            cen2.append(round(center[i], 3))
        self.assertEqual(m.ndihe, self.mv.dpo['ndihe']['value'])
        self.assertEqual(m.types, self.mv.dpo['types']['value'])
        self.assertEqual(cen2, self.mv.dpo['about']['value'])
        #self.assertEqual(m.center, self.mv.dpo['about']['value'])
        self.assertEqual(filename, self.mv.dpo.ligand_filename)
   

    def test_dpf_read_empty_ligand(self):
        """checks empty ligand
        """
        self.assertRaises(IOError, self.mv.ADdpf4_readFormattedLigand, " ")


    def test_dpf_read_non_existent_ligand(self):
        """checks non-existent ligand
        """
        self.assertRaises(IOError, self.mv.ADdpf4_readFormattedLigand, "asd.hfd.dpf")

    
    def test_dpf_read_ligand_widget_exists(self):
        """checks for widget whem read ligand called
        """
        self.mv.ADdpf4_readFormattedLigand('1ebg_lig.pdbqt')
        c = self.mv.ADdpf4_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(), 1)
        self.assertEqual(c.form.root.withdraw(),'')

     
    def test_search_parameters_simulated_annealing_replace(self):
        """checks after replacing
        """
        self.mv.ADdpf_setDpo(rtrf='0.5')
        self.assertEqual(self.mv.dpo['rtrf']['value'],'0.5')
        

    def test_search_parameters_ga_parameters_change(self):
        """checks after replacing
        """
        d={}
        d['ga_mutation_rate'] =0.5 
        apply(mv.ADdpf_setGAparameters, (), d)
        self.assertEqual(self.mv.dpo['ga_mutation_rate']['value'],0.5)
               
    
    def test_search_parameters_ga_parameters_values(self):
        """checks values in widget and file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr = open(testfile)
        alllines = fptr.readlines()
        fptr.close()
        ll = [0, 0]
        for i in alllines:        
            if find(i,'ga_window_size')==0:
                ll=split(i)
                break
        self.assertEqual(str(mv.dpo['ga_window_size']['value']), ll[1])
    

    def test_search_parameters_ga_parameters_replace(self):
        """checks in file after replacing in widget
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        d={}
        d['ga_pop_size'] = 2
        apply(self.mv.ADdpf_setGAparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0, 0]
        for i in alllines:        
            if find(i,'ga_pop_size')==0:
                ll=split(i)
                break
        self.assertEqual(ll[1],'2')
        
   
    def test_search_parameters_ls_parameters_values(self):
        """checks after replacing ls parameter
        """
        d={}
        d['ls_search_freq'] =0.5 
        apply(mv.ADdpf_setLSparameters, (), d)
        self.assertEqual(self.mv.dpo['ls_search_freq']['value'],0.5)
   

    def test_search_parameters_ls_parameters_replace(self):
        """checks ls  parameters in widget and file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        d={}
        d['ls_search_freq'] = 0.02 
        apply(mv.ADdpf_setLSparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        ll = [0, 0]
        for i in alllines:        
            if find(i,'ls_search_freq')==0:
                ll=split(i)
                break
        self.assertEqual(str(round(mv.dpo['ls_search_freq']['value'],2)),ll[1])
        

    def test_search_parameters_ls_parameters_change(self):
        """checks in file after replacing ls parameters in widget
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        d={}
        d['ls_search_freq'] = 0.02
        apply(mv.ADdpf_setLSparameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0, 0]
        for i in alllines:        
            if find(i,'ls_search_freq')==0:
                ll=split(i)
                break
        self.assertEqual(ll[1],'0.02')
   

    def test_search_parameters_docking_parameters_values(self):
        """checks docking parameters after replacing
        """
        d={}
        d['rmstol'] = 4.0 
        apply(mv.ADdpf_setDockingParameters, (), d)
        self.assertEqual(self.mv.dpo['rmstol']['value'], 4.0)


    def test_search_parameters_docking_parameters_replace(self):
        """checks docking  paarmeters in widget and file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        test_val = 123
        d={}
        d['sw_max_fail'] = test_val
        apply(mv.ADdpf_setDockingParameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for line in alllines:        
            if find(line,'sw_max_fail')>-1:
                ll=split(line)
                break
        self.assertEqual(test_val,int(ll[1]))
        self.assertEqual(self.mv.dpo['sw_max_fail']['value'],test_val)
         

    def test_search_parameters_docking_parameters_change(self):
        """checks in file after replacing ls parameters in widget
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        test_val = 321
        d={}
        d['sw_max_its'] =  test_val
        apply(mv.ADdpf_setDockingParameters, (), d)
        testfile = "somename.dpf"
        self.mv.ADdpf4_writeGALS(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        fptr.close()
        ll = [0,0]
        for i in alllines:        
            if find(i,'sw_max_its')==0:
                ll=split(i)
                break
        self.assertEqual(int(ll[1]),test_val)


    def test_sa_dpf_compare_lines(self):
        
        """checks ref4_SA file and test_SA file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        self.mv.ADdpf4_writeSA("test_SA.dpf")
        testptr = open("test_SA.dpf")
        testlines = testptr.readlines()
        refptr = open("ref4_SA.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)
            

    def test_ga_dpf_compare_lines(self):
        
        """checks ref4_GA file and test_GA file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        self.mv.ADdpf4_writeGA("test_GA.dpf")
        testptr = open("test_GA.dpf")
        testlines = testptr.readlines()
        refptr = open("ref4_GA.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)
            #ref_types = set(refline.split()[1:6] )
            #test_types = set(testline.split()[1:6] )
            #self.assertEqual(ref_types,test_types)

    def test_ls_dpf_compare_lines(self):
        
        """checks ref4_LS file and test_LS file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        self.mv.ADdpf4_writeLS("test_LS.dpf")
        testptr = open("test_LS.dpf")
        testlines = testptr.readlines()
        refptr = open("ref4_LS.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            if refline.find("ligand_types")>-1:
                ref_words = refline.split()
                test_words = testline.split()
                self.assertEqual(len(ref_words),len(test_words))
                for w in ref_words:
                    assert w in test_words
            else:
                self.assertEqual(strip(refline), strip(testline))


    def test_gals_dpf_compare_lines(self):
        
        """checks ref4_GALS file and test_GALS file are same
        """
        self.mv.ADdpf4_readFormattedLigand("1ebg_lig.pdbqt")
        self.mv.ADdpf4_readMacromolecule("1ebg_rec.pdbqt")
        self.mv.ADdpf4_writeGALS("test_GALS.dpf")
        testptr = open("test_GALS.dpf")
        testlines = testptr.readlines()
        refptr = open("ref4_GALS.dpf")
        reflines = refptr.readlines()
        refptr.close()
        for refline,testline in zip(reflines,testlines):
            if refline.find("ligand_types")>-1:
                ref_words = refline.split()
                test_words = testline.split()
                self.assertEqual(len(ref_words),len(test_words))
                for w in ref_words:
                    assert w in test_words
            else:
                self.assertEqual(strip(refline), strip(testline))


class ADdpf4_flexResTests(ADdpf4_BaseTests):

    #read receptor
    def test_dpf4_select_rigid_macro_mol(self):
        """select a rigid receptor and checks dpo receptor_filename 
        """
        filename = 'hsg1_rigid.pdbqt'
        self.mv.ADdpf4_readMacromolecule(filename)
        self.assertEqual(self.mv.dpo.receptor_filename,filename)


    #read ligand
    def test_dpf4_read_flex_mol(self):
        """reads flexible input file and checks dpo ligand_filename 
        """
        filename = 'hsg1_flex.pdbqt'
        self.mv.ADdpf4_readFormattedLigand(filename)
        ligand_name = self.mv.Mols[0].name
        self.assertEqual(self.mv.dpo.ligand.name, ligand_name)
        self.assertEqual('ARG8' in self.mv.Mols[0].chains.residues.name, True)
        args = self.mv.Mols[0].chains.residues.get(lambda x:x.name=='ARG8')
        self.assertEqual(len(args), 2)
        self.assertEqual(len(args.atoms.bonds[0])>0, True)
    

    #choose ligand
    def test_dpf4_choose_flex_mol(self):
        """readin then choose flexible input file. check dpo ligand_filename 
        """
        filename = 'hsg1_flex.pdbqt'
        self.mv.readMolecule(filename)
        ligand_name = self.mv.Mols[0].name
        self.assertEqual('ARG8' in self.mv.Mols[0].chains.residues.name, True)
        args = self.mv.Mols[0].chains.residues.get(lambda x:x.name=='ARG8')
        self.assertEqual(len(args), 2)
        self.assertEqual(len(args.atoms.bonds[0])>0, True)
        self.mv.ADdpf4_chooseFormattedLigand(ligand_name)
        self.assertEqual(self.mv.dpo.ligand.name, ligand_name)



class ADdpf4_formatting_flexResTests(ADdpf4_BaseTests):

    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()
        for m in self.mv.Mols:
            self.mv.deleteMol(m)
        self.mv.loadModule('autoflexCommands', 'AutoDockTools')
        self.mv.readMolecule('hsg1.pdbqt', ask=0, parser=None)
        self.mv.ADflex_chooseMacro("hsg1")
        from MolKit.molecule import Atom
        self.mv.setIcomLevel(Atom, KlassSet=None)
        self.mv.ADflex_setResidues("::ARG8")
        self.mv.ADflex_setBondRotatableFlag("hsg1:B:ARG8:NE,CZ;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:B:ARG8:CZ,NH1;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:B:ARG8:CZ,NH2;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:A:ARG8:NE,CZ;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:A:ARG8:CZ,NH1;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:A:ARG8:CZ,NH2;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:B:ARG8:CA,CB;", False)
        self.mv.ADflex_setBondRotatableFlag("hsg1:A:ARG8:CA,CB;", False)
        self.mv.ADflex_writeFlexFile('temp_FLEX.pdbqt')
        self.mv.ADflex_writeRigidFile('temp_RIGID.pdbqt')


    #choose receptor
    def test_dpf4_choose_rigid_mol(self):
        """choose new rigid file. check dpo macro_filename 
        """
        written_macro_name = "temp_RIGID.pdbqt"
        self.mv.ADdpf4_readMacromolecule(written_macro_name)
        macro_name = "temp_RIGID"
        self.assertEqual(self.mv.dpo.receptor_stem, macro_name)
        self.assertEqual(self.mv.dpo['fld']['value'], macro_name+".maps.fld")



class ADdpf4_FlexRes_Lig_Order_Tests(ADdpf4_BaseTests):

    def test_gpf4_lig_flexres(self):
        """flexResTests: read a ligand file then a flexres file and check written types
        """
        rigid_filename = 'CathepsinB_rigid.pdbqt'
        flexres_filename = 'CathepsinB_flex.pdbqt'
        ligand_filename = 'FGA3.pdbqt'
        output_filename = 'lig_flexres.dpf'
        self.mv.ADdpf4_readMacromolecule(rigid_filename)
        self.mv.ADdpf4_readFormattedLigand(ligand_filename)
        self.mv.ADdpf4_readFlexRes(flexres_filename)
        self.mv.ADdpf4_writeGALS(output_filename, log=0)
        fptr = open(output_filename)
        lines = fptr.readlines()
        types_line = lines[4]
        ref_line = "ligand_types A C OA HD N SA          # atoms types in ligand\n"
        self.assertEqual(types_line,ref_line)


    def test_gpf4_flexres_lig(self):
        """flexResTests: read a flexres file then a ligand file and check written types
        """
        rigid_filename = 'CathepsinB_rigid.pdbqt'
        flexres_filename = 'CathepsinB_flex.pdbqt'
        ligand_filename = 'FGA3.pdbqt'
        output_filename = 'flexres_lig.dpf'
        self.mv.ADdpf4_readMacromolecule(rigid_filename)
        self.mv.ADdpf4_readFlexRes(flexres_filename)
        self.mv.ADdpf4_readFormattedLigand(ligand_filename)
        self.mv.ADdpf4_writeGALS(output_filename)
        fptr = open(output_filename)
        lines = fptr.readlines()
        types_line = lines[4]
        ref_line = "ligand_types A C OA HD N SA          # atoms types in ligand\n"
        self.assertEqual(types_line,ref_line)


    
    
    def test_rig_flex_lig(self):
        """set rigid filename, flexfilename and open ligand
        """ 
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_writeGALS('./zero_FE_rig_GALS.dpf', log=0)
        c=self.mv.dpo
        self.assertEqual(c['ligand_types']['value'], 'C FE')

    
    def test_rig_lig_flex(self):
        """set rigid filename, open ligand and set flexfilename
        """ 
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_writeGALS('./zero_FE_rig_GALS.dpf', log=0)
        c=self.mv.dpo
        self.assertEqual(c['ligand_types']['value'], 'C FE')

    
    def test_flex_rig_lig(self):
        """set  flex filename, rigid filename and open ligand
        """ 
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        c=self.mv.dpo
        self.mv.ADdpf4_writeGALS('./zero_rig_GALS.dpf', log=0)
        self.assertEqual(c['ligand_types']['value'], 'C FE')

    
    def test_flex_lig_rig(self):
        """set  flex filename, open ligand and set rigid filename
        """ 
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        c=self.mv.dpo
        self.mv.ADdpf4_writeGALS('./zero_rig_GALS.dpf', log=0)
        self.assertEqual(c['ligand_types']['value'], 'C FE')

    
    def test_lig_rig_flex(self):
        """set open ligand, set rigid filename and set flex filename
        """ 
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_writeGALS('./zero_rig_FE_GALS.dpf', log=0)
        c=self.mv.dpo
        self.assertEqual(c['ligand_types']['value'], 'C FE')

    
    def test_lig_flex_rig(self):
        """set open ligand, set flex filename and set rigid filename
        """ 
        self.mv.ADdpf4_readFormattedLigand('./ind_zero.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_LIGAND_TYPES, ['C'])
        self.mv.ADdpf4_readFlexRes('./hsg1_FE.pdbqt', log=0)
        self.assertEqual(self.mv.DPF_FLEXRES_TYPES, ['FE'])
        self.mv.ADdpf4_readMacromolecule('./hsg1_rigid.pdbqt', log=0)
        self.mv.ADdpf4_writeGALS('./zero_FE_rig_GALS.dpf', log=0)
        c=self.mv.dpo
        self.assertEqual(c['ligand_types']['value'], 'C FE')



if __name__ == '__main__':
    #unittest.main()
    test_cases = [
        'ADdpf4_BaseTests',
        'ADdpf4_readDPFTests',
        'ADdpf4_flexResTests',
        'ADdpf4_formatting_flexResTests',
        'ADdpf4_FlexRes_Lig_Order_Tests',
            ]
    unittest.main( argv=([__name__ ,] + test_cases) )






#
#
#
#
# $Id: test_AromaticCarbonManager.py,v 1.2 2004/08/25 20:47:52 rhuey Exp $
#

import unittest
from AutoDockTools.atomTypeTools import AromaticCarbonManager


class BaseTests(unittest.TestCase):
    def setUp(self):
        from MolKit import Read
        self.mol = Read('ligandfiles/mtx.mol2')[0]
        self.mol.buildBondsByDistance()
        self.mol.allAtoms.autodock_element = self.mol.allAtoms.element
    

    def tearDown(self):
        """
        clean-up
        """
        del(self.mol)


    def test_constructor(self):
        """
        instantiate an AromaticCarbonManager
        """
        ACM = AromaticCarbonManager()
        self.assertEquals(ACM.__class__, AromaticCarbonManager)



    def test_setAromaticCarbons(self):
        """
         test that AromaticCarbonManager sets AromaticCarbons using cutoff
        """
        ACM = AromaticCarbonManager()
        aromCs_default = ACM.setAromaticCarbons(self.mol)
        self.assertEquals(len(aromCs_default), 0)
        aromCs_10 = ACM.setAromaticCarbons(self.mol, cutoff=10)
        self.assertEquals(len(aromCs_10), 6)
        aromCs_40 = ACM.setAromaticCarbons(self.mol, cutoff=40)
        self.assertEquals(len(aromCs_40), 12)


    def test_change_aromatic_criteria(self):
        """
         test change_aromatic_criteria
        """
        ACM = AromaticCarbonManager()
        aromCs_default = ACM.setAromaticCarbons(self.mol)
        self.assertEquals(len(aromCs_default), 0)
        ACM.change_aromatic_criteria(40)
        aromCs_40 = ACM.setAromaticCarbons(self.mol)
        self.assertEquals(len(aromCs_40), 12)


    def test_set_carbon_names(self):
        """
         test setting carbon names
        """
        ACM = AromaticCarbonManager()
        aromCs_40 = ACM.setAromaticCarbons(self.mol, cutoff=40)
        otherCs = self.mol.allAtoms.get(lambda x: x.autodock_element=='C')
        aliphaticCs = ACM.set_carbon_names(aromCs_40, 'C')
        self.assertEqual(len(aromCs_40), len(aliphaticCs))
        newCs = self.mol.allAtoms.get(lambda x: x.autodock_element=='C')
        self.assertEqual(len(newCs), len(otherCs + aliphaticCs))
        aromCs = ACM.set_carbon_names(aromCs_40, 'A')
        #test setting them back to Cs
        As = self.mol.allAtoms.get(lambda x: x.autodock_element=='A')
        self.assertEqual(len(aromCs_40), len(As))


if __name__ == '__main__':
    unittest.main()



#
#
#  $Id: test_ADgpf.py,v 1.11 2010/05/26 21:45:39 annao Exp $
#
#

import unittest, glob, os, sys
from string import strip, find, split
import time
from MolKit.molecule import Atom

mv = None
ct = 0
totalCt = 42


class ADgpf_BaseTests(unittest.TestCase):
    """
    setUp + tearDown form a fixture: working environment for the testing code
    """
    
        
    def startViewer(self):
        global mv
        #print 'in test_AD startViewer'
        if mv is None:
            from MolKit import Read
            import Tkinter
            from Pmv.moleculeViewer import MoleculeViewer
            mv = MoleculeViewer(trapExceptions=False)
            mv.loadModule('autotorsCommands', 'AutoDockTools')
            mv.loadModule('autogpfCommands', 'AutoDockTools')
            mv.loadModule('autodpfCommands', 'AutoDockTools')
            #8/18:
            mv.loadModule('autoanalyzeCommands', 'AutoDockTools')
            mv.loadModule('deleteCommands', 'Pmv')
            mv.loadModule('selectionCommands', 'Pmv')
            #change warningMsg format
            mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
            
        self.mv = mv


    def setUp(self):
        """
        clean-up
        """
        if not hasattr(self, 'mv'):
            self.startViewer()
        for m in self.mv.Mols:
            self.mv.deleteMol(m)


    def tearDown(self):
        """
        clean-up
        """
        #print 'in gpf tearDown'
        global ct, totalCt
        #reset gridparameter object
        from AutoDockTools.GridParameters import GridParameters
        self.mv.gpo = GridParameters()
        self.mv.gpo.vf=self.mv

        #delete any molecules left due to errors
        for m in self.mv.Mols:
            self.mv.deleteMol(m)

        ct = ct + 1
        #print 'ct =', ct
        if ct==totalCt:
            print 'destroying mv'
            self.mv.Exit(0)
            del self.mv       
    
        

class ADgpf_readgpfTests(ADgpf_BaseTests):
    
    
    def test_gp_read_macro_mol(self):
        """reads a macro mol and checks gpo receptor_filename 
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.assertEqual(self.mv.gpo.receptor_filename,"hsg1.pdbqs")
    

    def test_gp_read_empty_macro_mol(self):
        
        """reads a empty macro mol and checks that IOError is raised
        """
        self.assertRaises(IOError,self.mv.ADgpf_readMacromolecule," ")

    
    def test_gp_read_non_existent_macro_mol(self):
        """reads a non-exixtent macro mol and checks that IOError is raised
        """
        self.assertRaises(IOError,self.mv.ADgpf_readMacromolecule,"gfdjs.pdbqs")

       
    def test_gp_choose_macro_mol_name(self):
        """checks chosen macrol name =mv.Mols[0]
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_chooseMacromolecule("hsg1")
        self.assertEqual(self.mv.Mols[0].name,"hsg1")


    def test_gp_choose_macro_mol_widget(self):
        
        """checks widget of choose macro mol
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_chooseMacromolecule("hsg1")
        c=mv.ADgpf_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        c.Close_cb()
            

    def test_gp_add_solvation_parameters_comparison(self):
        
        """compares two files in add solvation parameters after writing
        """
        
        mol=self.mv.readMolecule('hsg1.pdb')[0]
        self.mv.setIcomLevel(Atom, KlassSet=None)
        self.mv.selectFromString(mols='',chains='',res= 'HOH*',atoms='*', negate=0, silent=1)
        self.mv.deleteAtomSet(self.mv.getSelection())
        self.mv.add_hGC("hsg1:::", polarOnly=1, renumber=1)
        testname='test_hsg1.pdbqs'
        self.mv.ADgpf_addSolvationParameters(mol,testname)
        testptr=open('test_hsg1.pdbqs')
        testlines=testptr.readlines()
        if find(testlines[0], 'REMARK')>-1:
            testlines = testlines[1:]
        realptr=open('ref.pdbqs')
        reallines=realptr.readlines()
        if find(reallines[0], 'REMARK')>-1:
            reallines = reallines[1:]
       
        for realline,testline in zip(reallines,testlines):
            if find(testline, '-0.000')> -1 or find(realline, '-0.000')>-1:
                #allow 0.000 to match -0.000
                realS = strip(realline)
                testS = strip(testline)
                #compare up to zero
                self.assertEqual(realS[:70], testS[:70])
                #THIS SKIPS space 70 which has '-' sign on linux
                #compare unsigned zeros to the end
                self.assertEqual(realS[71:], testS[71:])
            else:
                self.assertEqual(strip(realline), strip(testline))
    

    def test_gp_add_solvation_paramters_replace_values(self):
        
        """checks by changing sol_par 
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_chooseMacromolecule("hsg1")
        c={}
        c['sol_par']=0.5
        apply(mv.ADgpf_setGpo, (), c)
        self.assertEqual(self.mv.gpo['sol_par']['value'],0.5)
    
    
    def test_gp_set_map_types_directly_widget(self):
        
        """checks for widget of set map types
        """
        self.mv.ADgpf_readFormattedLigand("ind.out.pdbq")

        self.mv.ADgpf_setMapTypes("CAONSH",1,1,0)
        v=self.mv.ADgpf_initLigand
        self.assertEqual(v.form.root.winfo_ismapped(),1)
        v.Close_cb()
                

    def test_gp_set_map_types_directly_change_values(self):
        """checks by changing parmaters values
        """
                
        self.mv.ADgpf_setMapTypes("CAONSH",1,1,0)
        self.assertEqual(self.mv.gpo['types']['value'],"CAONSH")
        self.assertEqual(self.mv.gpo['NHB']['value'],1)
        self.assertEqual(self.mv.gpo['OHB']['value'],1)
        self.assertEqual(self.mv.gpo['SHB']['value'],0)
    

    def test_gp_set_map_types_values_in_widget(self):
        
        """checks values in widget after setting them using command
        """
        c=self.mv.ADgpf_setMapTypes
        c.gtypes.set("CAONSH")
        c.OHBonds.set(1)
        self.assertEqual(self.mv.gpo['OHB']['value'],1)
        self.assertEqual(self.mv.gpo['types']['value'],"CAONSH")
        c.OHBonds.set(0) 


    def test_gp_set_map_types_values_in_widget_update_hbonds(self):
        
        """checks by updating H bonds in atom type and checks when Hbonds are
        absent o,s,n 
        """
        
        c=self.mv.ADgpf_setMapTypes
        c.buildForm()
        self.assertEqual(c.OHBonds.get(),0) 
        self.assertEqual(c.NHBonds.get(),0)
        self.assertEqual(c.SHBonds.get(),0)
        c.updateHbonds()
        c.OHBonds.set(1)
        c.NHBonds.set(1)
        c.SHBonds.set(1)
        self.assertEqual(self.mv.gpo['types']['value'],"CAONSH")
        self.assertEqual(self.mv.gpo['OHB']['value'],1) 
        self.assertEqual(self.mv.gpo['NHB']['value'],1)
        self.assertEqual(self.mv.gpo['SHB']['value'],1)
        c.Accept_cb()
    
    
    def test_gp_set_map_types_directly_invalid_values(self):
        
        """checks by changing parameters values to invalid
        """
        self.mv.ADgpf_setMapTypes("CAONSH",1,'a',0)
        self.assertRaises(TypeError,self.mv.ADgpf_setMapTypes.OHBonds.get(),'a')


    def test_gp_set_map_types_directly_atoms_in_list(self):
        """checks the entry of map atom types
        """
        var='bc'
        types=['C','A','N','O','S','P','H','n','f','F','c','b','I','M']
        for i in range(0,len(var)):
             for l in types:      
                    if find(l,var[i])==0:
                        break;
                    else:        
                        self.mv.ADgpf_setMapTypes(var,1,1,0)
                        self.assertEqual(mv.gpo['types']['value'],'bc')
                
    
    def test_gp_set_map_types_directly_invalid_map_atom_types(self):
        """checks by changing parmaters values to invalid
        """
        c = self.mv.ADgpf_setMapTypes        
        self.assertEqual(c.gtypes.get()=='a', False)

 
    def test_gp_choose_ligand_name(self):
        """checks ligand name
        """
        self.mv.ADgpf_readFormattedLigand('ind.out.pdbq')
        self.mv.ADgpf_chooseFormattedLigand("ind_out")
        self.assertEqual(self.mv.gpo.ligand.name,self.mv.Mols[0].name)


    def test__gp_choose_ligand_name_widget(self):
        """checks widget for choose ligand name
        """
        self.mv.ADgpf_readFormattedLigand('ind.out.pdbq')
        self.mv.ADgpf_chooseFormattedLigand("ind_out")
        c=mv.ADgpf_initLigand
        c.form
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        c.Close_cb()
        
    
    def test_gpf_length_of_file(self):
        """checks no. of lines in gpf file
        """
        fptr=open("hsg1.gpf")
        alllines=fptr.readlines()
        self.assertEqual(len(alllines),60)


    def test_gpf_replace_random(self):
        """ checks by setting some values in place of random
        """
        self.mv.ADgpf_readGPF("hsg1.gpf")               
        self.mv.ADgpf_readFormattedLigand("ind.out.pdbq")
        teststring = "1.0"
        self.mv.ADgpf_setGpo(sol_par=teststring)
        testfile = "hsg2.gpf"
        self.mv.ADgpf_writeGPF(testfile)
        fptr=open(testfile)
        alllines=fptr.readlines()
        for l in alllines:
            if find(l, 'sol_par')>0:
                 ll=split(alllines[find(l, 'sol_par')])
            else:
                break
            self.assertEqual(ll[i], teststring)
   

    def test_gpf_read_formatted_ligand(self):
        """checks read ligand name
        """
        self.mv.ADgpf_readFormattedLigand('ind.out.pdbq')
        self.assertEqual(self.mv.gpo.ligand_filename,'ind.out.pdbq')


    def test_gpf_read_empty_formatted_ligand(self):
        """checks empty ligand name
        """
        self.assertRaises(IOError,self.mv.ADgpf_readFormattedLigand," ")
        
    
    def test_gpf_read_non_existent_formatted_ligand(self):
        """checks non_existent ligand name
        """
        self.assertRaises(IOError,self.mv.ADgpf_readFormattedLigand,"hjgf.pdbq ")

       
    def test_gpf_set_new_parms_for_new_atom_type(self):
        """ checks values of set new params in widget after assigning
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        s=self.mv.ADgpf_defineAtomParameters
        s.elem.set("C")
        oldRij = s.Rij.get()
        s.Rij.set(1.0)
        oldepsij = s.epsij.get()
        s.epsij.set(2.0)
        self.assertEqual(s.elem.get(),"C")
        self.assertEqual(s.Rij.get(),'1.0')
        self.assertEqual(s.epsij.get(),'2.0')
        s.Rij.set(oldRij)
        s.epsij.set(oldepsij)
    
    
    def test_gpf_set_new_parms_for_new_atom_type_invalid(self):
        """checks by entering invalid parameters in setnew params
        """
        self.assertEqual(self.mv.ADgpf_defineAtomParameters.elem.get()=='W', False)
    

    def test_gpf_set_new_parms_for_new_atom_type_widget(self):
        """checks set new params for new atom type widget
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        s=self.mv.ADgpf_defineAtomParameters
        s.elem.set("C")
        oldRij = s.Rij.get()
        s.Rij.set(1.0)
        oldepsij = s.epsij.get()
        s.epsij.set(2.0)
        c=mv.ADgpf_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        s.Rij.set(oldRij)
        s.epsij.set(oldepsij)
        c.Close_cb()
         
    
    def test_gpf_set_up_covalent_map_widget(self):
        """checks set up covalent map widget
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_setUpCovalentMap('-22.9870 -0.0600 4.4430',-1.0,'5.0','1000.0','CAONSHZ')
        c=mv.ADgpf_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        c.Close_cb()
            
    
    def test_gpf_set_up_covalent_map_coords(self):
        """ checks covalent coords  in set up covalent map
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_readFormattedLigand('ind.out.pdbq')
        #c={}
        #c['covalent_coords']='-3.884'
        #apply(self.mv.ADgpf_setUpCovalentMap,(),c)
        self.mv.ADgpf_setUpCovalentMap('-22.9870 -0.0600 4.4430',-1.0,'5.0','1000.0','CAONSHZ')
        self.assertEqual(str(self.mv.gpo['covalent_coords']['value']),'-22.9870 -0.0600 4.4430')

    
    def test_gpf_get_values_from_gpf_read(self):
        """checks gpf filename
        """
        self.mv.ADgpf_readGPF('hsg1.gpf')
        c=self.mv.gpo
        self.assertEqual(c.gpf_filename,"hsg1.gpf")
    

    def test_gpf_get_values_from_gpf_read_empty(self):
        """checks empty gpf file name
        """
        self.assertRaises(IOError,self.mv.ADgpf_readGPF," ")
    

    def test_gpf_get_values_from_gpf_read_non_existent(self):
        """checks non existent gpf file name
        """
        self.assertRaises(IOError,self.mv.ADgpf_readGPF,"hsfh.gpf")

    
    def test_gpf_write_gpf(self):
        """checks ref_hsg1.gpf test_hsg1.gpf
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_readFormattedLigand('ind.out.pdbq')
        self.mv.ADgpf_writeGPF("test_hsg1.gpf")
        testptr = open("test_hsg1.gpf")
        testlines = testptr.readlines()
        refptr = open("ref_hsg1.gpf")
        reflines = refptr.readlines()
        for refline,testline in zip(reflines,testlines):
            self.assertEqual(refline,testline)
        c=mv.ADgpf_initLigand
        c.Close_cb()


    def test_set_up_grid_widget(self):
        """ checks for set up grid widget
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_setGrid.buildForm()
        self.mv.ADgpf_setGrid((0.369,-0.215,-4.987),(1,0,0),0.5)
        c=self.mv.ADgpf_setGrid
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        c.Close_cb()
        self.mv.ADgpf_setGrid.Accept_cb()
        

    def test_set_up_grid_coords(self):
        """ checks center coords in grid options widget and Mol
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        #have to build the form in order to create the Tkinter variables
        self.mv.ADgpf_setGrid.buildForm()
        self.mv.ADgpf_setGrid((2.428,0.812,-7.490),(1,0,0),0.5)
        #X center
        self.assertEqual(str(round(self.mv.Mols[-1].center[0],3)),'2.428')
        #Y center
        self.assertEqual(str(round(self.mv.Mols[-1].center[1],3)),'0.812')
        #Z center
        self.assertEqual(str(round(self.mv.Mols[-1].center[2],3)),'-7.49')
        #close the form opened by call to buildForm 
        self.mv.ADgpf_setGrid.Accept_cb()


    def test_set_up_grid_selected_atom_coords(self):
        """checks coords of grid after selecting an atom
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        
        self.mv.ADgpf_setGrid.buildForm()
        self.mv.ADgpf_selectCenter("hsg1:A:LYS70:CE")
        c=self.mv.ADgpf_setGrid
        d={}
        d['spacing']=0.5
        d['gridcenter']=(2.428,0.812,-7.490)
        d['npts']=(2,4,6)
        apply(c, (),d)
        #X center
        self.assertEqual(str(c.xCen.get()),'2.428')
        #Y center
        self.assertEqual(str(c.yCen.get()),'0.812')
        #Z center
        self.assertEqual(str(c.zCen.get()),'-7.49')
        self.mv.ADgpf_setGrid.Accept_cb()


    def test_set_up_grid__value_of_spacewheel(self):
        """checks space wheel value in set up grid
        """
        self.mv.ADgpf_readMacromolecule('hsg1.pdbqs')
        self.mv.ADgpf_setGrid.buildForm()
        c=self.mv.ADgpf_setGrid
        d={}
        d['spacing']=0.375
        d['gridcenter']=(2.428,0.812,-7.490)
        d['npts']=(2,4,6)
        apply(c, (),d)
        self.assertEqual(str(c.spacewheel.get()),'0.375')
        self.mv.ADgpf_setGrid.Accept_cb()


    def test_set_up_other_options_widget(self):
        """checks widget of set other options
        """
        self.mv.ADgpf_readMacromolecule("hsg1.pdbqs")
        self.mv.ADgpf_readFormattedLigand("ind.out.pdbq")
        self.mv.ADgpf_setOtherOptions(0.6,1,0.146)
        c=mv.ADgpf_initLigand
        self.assertEqual(c.form.root.winfo_ismapped(),1)
        c.Close_cb()
                
    
    def test_set_up_other_options_values(self):
        """checks smoothfactor,dielectric in set other options
        """
        self.mv.ADgpf_readMacromolecule("hsg1.pdbqs")
        c=self.mv.ADgpf_setOtherOptions
        g={}
        g['smooth']=0.6
        g['dielectric']=0.146
        apply(c, (),g)
        self.assertEqual(round(mv.gpo['smooth']['value'],3),0.60)
        self.assertEqual(round(mv.gpo['dielectric']['value'],3),0.146)
    

    def test_gpf_merge_non_polar_hydrogens(self):
        """checks number of atoms
        """
        m=self.mv.readMolecule('hsg1.pdb')[0]
        self.mv.setIcomLevel(Atom, KlassSet=None)
        self.mv.selectFromString(mols='',chains='',res= 'HOH*',atoms='*')
        self.mv.deleteAtomSet(self.mv.getSelection())
        self.mv.add_hGC("hsg1:::", polarOnly=0, renumber=1)
        self.mv.addKollmanCharges(m)
        orig_num_atoms=len(m.allAtoms)
        #self.mv.selectSet('nphs')
        nphs=m.allAtoms.get(lambda x:x.element=='H' and (x.bonds[0].atom1.element=='C' or x.bonds[0].atom2.element=='C'))
        len_nphs=len(nphs)
        c_nhps=m.allAtoms.get(lambda x:x.element=='C' and x.findHydrogens() > 0)
        #print "len(c_nphs)=", len(c_nphs)
        self.mv.ADgpf_mergeNonPolarHydrogens(m, outfile='xxxx.pdbqs')
        self.assertEqual(len(m.allAtoms),(orig_num_atoms)-(len_nphs))


    def test_gpf_merge_non_polar_hydrogens_charges(self):
        """checks atom charges after merging
        """
        m=self.mv.readMolecule('hsg1.pdb')[0]
        self.mv.setIcomLevel(Atom, KlassSet=None)
        self.mv.selectFromString(mols='',chains='',res= 'HOH*',atoms='*')
        self.mv.deleteAtomSet(self.mv.getSelection())
        self.mv.add_hGC("hsg1:::", polarOnly=0, renumber=1)
        self.mv.addKollmanCharges(m)
        #make a record of the charges on each nonpolarCarbon + its hydrogens
        c_nhps=m.allAtoms.get(lambda x:x.element=='C' and x.findHydrogens() > 0)
        #this dict keys are the nonpolarCarbons 
        #its values are their united charge [orig charge + charge on each nph]
        c_charges={}
        for c_atom in c_nhps:                                       
            hs=c_atom.findHydrogens()
            h_tot_charge=0
            for h in hs:
                h_tot_charge+=h.charge
            c_charges[c_atom]=c_atom.charge+h_tot_charge
        self.mv.ADgpf_mergeNonPolarHydrogens(m, outfile='xxxx.pdbqs')
        for c_atom in c_nhps:
            self.assertEqual(c_atom.charge, c_charges[c_atom])


    def test_gpf_init_ligand_name(self):
        """ checks ligand name read by init ligand
        """
        self.mv.ADgpf_readFormattedLigand("ind.out.pdbq")
        self.assertEqual(self.mv.gpo.ligand.name,'ind_out')



    def test_gpf_init_ligand_with_halogen(self):
        """ checks ligand with halogen sets types correctly
        """
        self.mv.ADgpf_readFormattedLigand("nutlin.pdbq")
        self.assertEqual(self.mv.gpo['types']['value'], 'CANOb')

                

    def test_gpf_init_Macro_name(self):
        """checks macro mol name read by init macro
        """
        self.mv.ADgpf_readMacromolecule("hsg1.pdbqs")
        self.assertEqual(self.mv.gpo.receptor_stem,'hsg1')
        

    def test_gpf_check_macro_types(self):
        """checks macro types
        """
        self.mv.ADgpf_readMacromolecule("hsg1.pdbqs")
        mol = self.mv.Mols[0]
        d = {}
        #build a list of atom autodock types for the mol
        for a in mol.allAtoms:
            d[a.autodock_element] = 1
        types = d.keys() #list of types in macro
        #checking that the gpo has all of those values
        for ch in self.mv.gpo['mset']['value']:
            self.assertEqual(ch in types, True)



if __name__ == '__main__':
    unittest.main()





from NetworkEditor.items import NetworkNode
class GetStructuresFromDir(NetworkNode):
    """
    Get list of structure file names from directory and create
    objects based on these files
    """
    mRequiredTypes = {}
    mRequiredSynonyms = [
    ]

    def __init__(self, constrkw = {},  name='GetStructuresFromDir', **kw):
        kw['constrkw'] = constrkw
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw)

        ip = self.inputPortsDescr
        ip.append({'name': 'directory', 'datatype': 'string'})

        self.widgetDescr['directory'] = {
            'class':'NEEntryWithDirectoryBrowser', 'master':'node', 'width':20,
            'initialValue':'', 'labelCfg':{'text':'Structure Directory: '}
            }

        op = self.outputPortsDescr
        op.append({'name': 'structure_list_obj', 'datatype': 'list'})

#        op = self.outputPortsDescr
#        op.append({'name': 'structure_list', 'datatype': 'list'})


        code = """def doit(self, directory):
        import glob, os
        from AutoDockTools.VisionInterface.Adt.receptor import receptor

        directory = os.path.abspath(directory)

        if directory == None:
            return 'stop'

        if directory is not None:
            cwd = os.getcwd()
            os.chdir(directory)
        try:
            filenames_pdbqt = glob.glob('*.pdbqt')
            filenames_pqr = glob.glob('*.pqr')
            filenames_pdb = glob.glob('*.pdb')

            structure_list = filenames_pdbqt

            for f in filenames_pqr:
                sid = f.rstrip('.pqr')
                s = sid + '.pdbqt'
                found = False
 
                for i in structure_list:
                    if i == s:
                        found = True        
                        break

                if found == False:
                    structure_list.append(f)

            for f in filenames_pdb:
                sid = f.rstrip('.pdb')
                found = False
 
                for i in structure_list:
                    if i == sid + '.pdb' or i == sid + '.pdbqt':
                        found = True        
                        break

                if found == False:
                    structure_list.append(f)

            structure_list = [os.path.join(directory, x) for x in filenames_pdbqt]
            structure_list_obj = [receptor(x) for x in structure_list]
        finally:
            if directory is not None:
                os.chdir(cwd)

        print "--------------------------------------------------------------"
        print "The following structures are found in the structure directory:"

        count = 0

        for i in structure_list:
            count = count + 1
            print str(count) + '. ' + i
           
        print "--------------------------------------------------------------"
        
        pass
#        self.outputData(structure_list_obj=structure_list_obj, structure_list=structure_list)
        self.outputData(structure_list_obj=structure_list_obj)
"""
        self.configure(function=code)


    def beforeAddingToNetwork(self, net):
        try:
            ed = net.getEditor()
        except:
            import traceback; traceback.print_exc()
            print 'Warning! Could not import widgets'




#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/prepare_gpf4.py,v 1.18 2011/06/14 17:25:51 rhuey Exp $
#

import string
import os.path
import glob
from MolKit import Read
from AutoDockTools.GridParameters import GridParameters, grid_parameter_list4
from AutoDockTools.GridParameters import GridParameter4FileMaker
from AutoDockTools.atomTypeTools import AutoDock4_AtomTyper


def usage():
    print "Usage: prepare_gpf4.py -l pdbqt_file -r pdbqt_file "
    print "     -l ligand_filename"
    print "     -r receptor_filename"
    print
    print "Optional parameters:"
    print "    [-i reference_gpf_filename]"
    print "    [-o output_gpf_filename]"
    print "    [-x flexres_filename]"
    print "    [-p parameter=newvalue. For example: -p ligand_types='HD,Br,A,C,OA' or p npts='60,60,66' or gridcenter='2.5,6.5,-7.5']"
    print "    [-d directory of ligands to use to set types]"
    print "    [-y boolean to center grids on center of ligand]"
    print "    [-n boolean to NOT size_box_to_include_ligand]"
    print "    [-I increment npts in all 3 dimensions by this integer]"
    print "    [-v]"
    print
    print "Prepare a grid parameter file (GPF) for AutoDock4."
    print
    print "   The GPF will by default be <receptor>.gpf. This"
    print "may be overridden using the -o flag."

    
if __name__ == '__main__':
    import getopt
    import sys

    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'vl:r:i:x:o:p:d:ynI:')
    except getopt.GetoptError, msg:
        print 'prepare_gpf4.py: %s' % msg
        usage()
        sys.exit(2)

    receptor_filename = ligand_filename = None
    list_filename = gpf_filename = gpf_filename = None
    output_gpf_filename = None
    flexres_filename = None
    directory = None
    parameters = []
    verbose = None
    center_on_ligand = False
    size_box_to_include_ligand = True
    npts_increment = 0
    ligand_types_defined = False
    for o, a in opt_list:
        if o in ('-v', '--v'):
            verbose = 1
        if o in ('-l', '--l'):
            ligand_filename = a
            if verbose: print 'ligand_filename=', ligand_filename
        if o in ('-r', '--r'):
            receptor_filename = a
            if verbose: print 'receptor_filename=', receptor_filename
        if o in ('-i', '--i'):
            gpf_filename = a
            if verbose: print 'reference_gpf_filename=', gpf_filename
        if o in ('-x', '--x'):
            flexres_filename = a
            if verbose: print 'flexres_filename=', flexres_filename
        if o in ('-o', '--o'):
            output_gpf_filename = a
            if verbose: print 'output_gpf_filename=', output_gpf_filename
        if o in ('-p', '--p'):
            parameters.append(a)
            if a.split('=')[0]=="ligand_types": ligand_types_defined = True
            if verbose: print 'parameters=', parameters
        if o in ('-d', '--d'):
            directory = a
            if verbose: print 'directory=', directory
        if o in ('-y', '--y'):
            center_on_ligand = True
            if verbose: print 'set center_on_ligand to ', center_on_ligand
        if o in ('-n', '--n'):
            size_box_to_include_ligand = False
            if verbose: print 'set size_box_to_include_ligand to ', size_box_to_include_ligand
        if o in ('-I', '--I'):
            npts_increment = int(a)
            if verbose: print 'set npts_increment to ', npts_increment
        if o in ('-h', '--'):
            usage()
            sys.exit()


    if (not receptor_filename) or (ligand_filename is None and directory is None and ligand_types_defined is False):
        print "prepare_gpf4.py: ligand and receptor filenames"
        print "                    must be specified."
        usage()
        sys.exit()

    gpfm = GridParameter4FileMaker(size_box_to_include_ligand=size_box_to_include_ligand,verbose=verbose)
    if gpf_filename is not None:
        gpfm.read_reference(gpf_filename)
    if ligand_filename is not None:
        gpfm.set_ligand(ligand_filename)
    gpfm.set_receptor(receptor_filename)
    if directory is not None:
        gpfm.set_types_from_directory(directory)
    if flexres_filename is not None:
        flexmol = Read(flexres_filename)[0]
        flexres_types = flexmol.allAtoms.autodock_element
        lig_types = gpfm.gpo['ligand_types']['value'].split()
        all_types = lig_types
        for t in flexres_types:
            if t not in all_types: 
                all_types.append(t)
        all_types_string = all_types[0]
        if len(all_types)>1:
            for t in all_types[1:]:
                all_types_string = all_types_string + " " + t
        gpfm.gpo['ligand_types']['value'] = all_types_string 
    for param_str in parameters:
        if param_str.find("parameter_file")>-1:
            parameters.append("custom_parameter_file=1")
            break
    for p in parameters:
        key,newvalue = string.split(p, '=')
        if key=='gridcenter' and newvalue.find(',')>-1:
            newvalue = newvalue.split(',')
            newvalue = string.join(newvalue)
        kw = {key:newvalue}
        apply(gpfm.set_grid_parameters, (), kw)
    #gpfm.set_grid_parameters(spacing=1.0)
    if center_on_ligand is True:
        gpfm.gpo['gridcenterAuto']['value'] = 0
        cenx,ceny,cenz = gpfm.ligand.getCenter()
        gpfm.gpo['gridcenter']['value'] = "%.3f %.3f %.3f" %(cenx,ceny,cenz)
    if npts_increment:
        orig_npts = gpfm.gpo['npts']['value']  #[40,40,40]
        if verbose: print "before increment npts=", orig_npts
        for ind in range(3):
            gpfm.gpo['npts']['value'][ind] += npts_increment
        if verbose: print "after increment npts =", gpfm.gpo['npts']['value']
    gpfm.write_gpf(output_gpf_filename)


#prepare_gpf4.py -l 1ebg_lig.pdbqt -r 1ebg_rec.pdbqt -p spacing=0.4 -p ligand_types="HD,Br,A,C,OA" -p npts="60,60,60" -i ref.gpf -o testing.gpf 




#$Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Tests/test_loadCommands.py,v 1.2 2010/05/26 21:45:39 annao Exp $
# Author: Sargis Dallakyan - sargis@scripps.edu
# Summary: Makes sure that all Pmv modules can be loaded.
#$Id: test_loadCommands.py,v 1.2 2010/05/26 21:45:39 annao Exp $
import unittest, sys, os, time
from mglutil.util.packageFilePath import findModulesInPackage
import AutoDockTools

class LoadTest(unittest.TestCase):
    """Base class for unittest"""
    def test_loadAllModules(self):
        from Pmv.moleculeViewer import MoleculeViewer
        mv = MoleculeViewer(customizer = './.empty', logMode = 'no',
                            withShell=0, trapExceptions=False)
        mv.setUserPreference(('warningMsgFormat', 'printed'), log = 0)
        packagePath = AutoDockTools.__path__[0]
        modules = findModulesInPackage(packagePath, "^def initModule")[packagePath]
        failedTest = []
        for module_py in modules:
            module = os.path.splitext(module_py)[0]
            print 'loading...' + module
            try:
                mv.loadModule(module, 'AutoDockTools')
            except:
                failedTest.append(module_py)
            
        self.assertEqual(failedTest,[])
        mv.Exit(0)
if __name__ == '__main__':
        unittest.main()

    



#!/usr/bin/env python
#
# 
#
# $Header: /opt/cvs/python/packages/share1.5/AutoDockTools/Utilities24/prepare_ligand_vif.py,v 1.2 2012/01/31 17:57:37 rhuey Exp $ 
#
import os 

from MolKit import Read
from string import split, strip




if __name__ == '__main__':
    import sys
    import getopt


    def usage():
        "Print helpful, accurate usage statement to stdout."
        print "Usage: prepare_ligand_vif.py -l filename"
        print
        print "    Description of command..."
        print "         -l     ligand_filename (.pdbqt format)"
        print "    Optional parameters:"
        print "        [-v]    verbose output"
        print "        [-o pdbqt_filename] (default output filename is ligand_filename_stem + '_L.pdbqt')"
        print "        [-P]    list of indicies of residues to write with LP dummy atoms '22,26,30,40,41,42' "
        print "        [-S]    list of indicies of residues to write with LS dummy atoms '15,17' "


    # process command arguments
    try:
        opt_list, args = getopt.getopt(sys.argv[1:], 'l:vo:P:S:h')
    except getopt.GetoptError, msg:
        print 'prepare_ligand_vif.py: %s' %msg
        usage()
        sys.exit(2)

    # initialize required parameters
    #-l: ligand
    ligand_filename =  None
    # optional parameters
    verbose = None

    #-o outputfilename
    outputfilename = None
    #-P LP_atom_residues
    LP_atom_residues = None
    #-S LS_atom_residues
    LS_atom_residues = None

    #'l:vo:P:S:'
    for o, a in opt_list:
        #print "o=", o, " a=", a
        if o in ('-l', '--l'):
            ligand_filename = a
            if verbose: print 'set ligand_filename to ', a
            outputfilename = ligand_filename.split('.')[0] + '_LLL.pdbqt'
            if verbose: print 'set outputfilename from ligand_filename to ', outputfilename
        if o in ('-v', '--v'):
            verbose = True
            if verbose: print 'set verbose to ', True
        if o in ('-o', '--o'):
            outputfilename = a
            if verbose: print 'set outputfilename to ', outputfilename
        if o in ('-P', '--P'):
            LP_atom_residues = a
            if LP_atom_residues.find(',')>-1:
                LP_atom_residues = map(int, split(a, ','))
            if verbose: print 'set LP_atom_residues to ', LP_atom_residues
        if o in ('-S', '--S'):
            LS_atom_residues = a
            if LS_atom_residues.find(',')>-1:
                LS_atom_residues = map(int, split(a, ','))
            if verbose: print 'set LS_atom_residues to ', LS_atom_residues
        if o in ('-h', '--'):
            usage()
            sys.exit()


    # check input 
    if not ligand_filename:
        print 'prepare_ligand_vif: ligand filename must be specified.'
        usage()
        sys.exit()
    
    if not LP_atom_residues:
        print 'prepare_ligand_vif: LP_atom_residues must be specified.'
        usage()
        sys.exit()

    if not LS_atom_residues:
        print 'prepare_ligand_vif: LS_atom_residues must be specified.'
        usage()
        sys.exit()
    
    if verbose: 
        print 'LP_atom_residues=', LP_atom_residues
        print 'LS_atom_residues=', LS_atom_residues
        print "reading ", ligand_filename

    # process ligand
    #??check that ligand in pdbqt format??
    ext = os.path.splitext(ligand_filename)[1]
    assert ext=='.pdbqt'
    fptr = open(ligand_filename)
    liglines = fptr.readlines()
    fptr.close()
    if verbose: print 'read ', len(liglines), ' lines from ', ligand_filename 
    
    optr = open(outputfilename, 'w')
    if verbose: print "writing ", outputfilename

    # check whether already has ROOT/ENDROOT/TORSDOF
    i = 0
    has_root = 0
    if liglines[i]=='ROOT\n':
        optr.write('ROOT\n')
        has_root = 1
        i+=1
    else:
        optr.write('ROOT\n')

    for j in liglines[i:]:
        ll = split(j)
        if j[0:4]in ['ATOM', 'HETA']:
            atname = strip(j[12:16])
            resnum = strip(j[22:26])
            if strip(atname)=='CA':
                optr.write(j)
                #@@ guard against duplicates?
                #if j[-4:].find("RP")<0:
                optr.write(j[:-4]+' RP\n') 
                if verbose: print "wrote RP"
                resnum = strip(resnum)
                if int(resnum) in LP_atom_residues:
                    optr.write(j[:-4]+' LP\n')
                    if verbose: print " LP ", resnum
                if int(resnum) in LS_atom_residues:
                    optr.write(j[:-4]+' LS\n')
                    if verbose: print " LS ", resnum
            else:
                optr.write(j)
        else:
            optr.write(j)
    if not has_root:
        optr.write("ENDROOT\n")
        optr.write("TORSDOF 0 \n")

    optr.close()

# To execute this command type:
#prepare_ligand_vif -l 1vzf.pdbqt -P 22,26,30,40,41,42 -S 15,17 -o 1vzf_L.pdbqt



#########################################################################
#
# Date: Nov 2001 Authors: Michel Sanner
#
#    sanner@scripps.edu
#
#       The Scripps Research Institute (TSRI)
#       Molecular Graphics Lab
#       La Jolla, CA 92037, USA
#
# Copyright: Michel Sanner and TSRI
#
#########################################################################

from NetworkEditor.items import NetworkNode
from AutoDockTools.VisionInterface.Adt.dpf_template import dpf_template
from AutoDockTools.VisionInterface.Adt.gpf_template import gpf_template

class MakeGpfDpfCopies(NetworkNode):
    """
    A node that takes a DPF, a GPF and a directory of pdb/pqr/pdbqt files and 
    makes copies of the DPF/GPF.  The DPF/GPF copies will have the basenames of the
    pdb/pqr/pdbqt files.  
  
    Input 1: GPF template file with the extension .gpf
    Input 2: DPF template file with the extension .dpf
    Input 3: A directory path to the PDB/PQR/PDBQT files
    Output 1:  List of all GPFs in the directory
    Output 2:  List of all DPFs in the directory
    Output 3:  Same as input 3
    """
    
    def __init__(self, name='MakeDPFCopies', **kw):
        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )

        kw['name'] = name
        apply( NetworkNode.__init__, (self,), kw )
        ip = self.inputPortsDescr
        ip.append(datatype='gpf_template', name='gpf_file', required=False)
        ip.append(datatype='dpf_template', name='dpf_file', required=False)
        ip.append(datatype='string', name='struct_dir', required=True)

        op = self.outputPortsDescr
        op.append(datatype='list', name='gpf_list')
        op.append(datatype='list', name='dpf_list')
        op.append(datatype='string', name='struct_dir')

        code = """def doit(self, gpf_file, dpf_file, struct_dir):
    import os
    import shutil
    from AutoDockTools.VisionInterface.Adt.dpf_template import dpf_template
    from AutoDockTools.VisionInterface.Adt.gpf_template import gpf_template

    if dpf_file == None and gpf_file == None:
        print "ERROR: DPF and GPF input missing"
        return 'stop'


    if dpf_file != None:
        dpf_file_path = dpf_file.fullpath

        if not(os.path.exists(dpf_file_path)):
            print "ERROR: DPF template file " + dpf_file_path + " does not exist!"
            return 'stop'

    if gpf_file != None:
        gpf_file_path = gpf_file.fullpath

        if not(os.path.exists(gpf_file_path)):
            print "ERROR: GPF template file " + gpf_file_path + " does not exist!"
            return 'stop'

    name_list = set()
    d = os.path.abspath(struct_dir)

    for i in os.listdir(struct_dir):
        if i.endswith(".pdbqt") or i.endswith(".pdb") or i.endswith(".pqr"):
            name_list.add(i.split('.')[0])

    dpf_list = []
    gpf_list = []

    if dpf_file != None:
        for i in name_list:
            d_dst = os.path.join(d, i + '.dpf')
            dpf_list.append(d_dst)       

            if not(os.path.exists(d_dst)):
                shutil.copyfile(dpf_file_path, d_dst)

    if gpf_file != None:
        for i in name_list:
            g_dst = os.path.join(d, i + '.gpf')
            gpf_list.append(g_dst)       

            if not(os.path.exists(g_dst)):
                shutil.copyfile(gpf_file_path, g_dst)
  

    self.outputData(dpf_list=dpf_list, gpf_list=gpf_list, struct_dir=struct_dir)
"""
        self.setFunction(code)
